This function check if data for the years and quarters selected are available at FAERS to be downloaded.

faers_available(years, quarters, force = FALSE, internal = FALSE)

Arguments

years

An atomic integer indicates years for which data are required.

quarters

An atomic character, only "q1", "q2", "q3", and "q4" are allowed.

force

A boolean value. If set to TRUE, it indicates the retrieval of information about all records' metadata in the FAERS Quarterly Data Extract Files Site, bypassing the cache.

internal

A boolean value. It determines whether to use the internal data associated with the package.

Value

A logical indicates FAERS can have data for the years and quarters required?

Examples

faers_available(c(2011, 2023), c("q1", "q2"))
#> → Using FAERS metadata from cached
#>   /home/wzy/.cache/R/faers/faers/metadata/faers_meta_data.rds
#>   Snapshot time: 2026-04-08 11:16:04.08792
#> [1] TRUE TRUE