Test whether years and quarters are before specified period

faers_before_period(years, quarters, y, q, inclusive = TRUE)

Arguments

years

An atomic integer indicates years to test.

quarters

An atomic character indicates quarters to test, only "q1", "q2", "q3", and "q4" are allowed.

y

An integer, specifying the period year.

q

A string, specifying the period quarter.

inclusive

A bool, whether to include the period specifid.

Value

An atomic logical with the same length of the max length of years and quarters.

Examples

faers_before_period(c(2011, 2012), c("q1", "q3"), 2011, "q2")
#> [1]  TRUE FALSE