R/signal-eventset.R
faers_phv_composite.RdBuild contingency tables for disproportionality analysis focusing on a specific
set of adverse events (e.g., irAEs). This function extends faers_phv_table
to handle composite event definitions.
faers_phv_composite(.object, .event_set, ..., .full, .object2)
# S4 method for class 'FAERSascii,ANY,FAERSascii,missing'
faers_phv_composite(
.object,
.event_set,
.event_type = "pt",
...,
.full,
.object2
)
# S4 method for class 'FAERSascii,ANY,missing,FAERSascii'
faers_phv_composite(
.object,
.event_set,
.event_type = "pt",
...,
.full,
.object2
)
faers_phv_signal_composite(.object, ...)
# S4 method for class 'FAERSascii'
faers_phv_signal_composite(
.object,
.event_set,
.methods = NULL,
...,
.phv_signal_params = list(),
BPPARAM = BiocParallel::SerialParam()
)A FAERSascii object. The unique number of primaryids from
.object will be regarded as n1..
A character vector of PT terms or a logical expression that defines the set of adverse events of interest.
Other arguments passed to specific methods.
A FAERSascii object with data from full database.
A FAERSascii object with data from another interested drug.
A character string specifying the type of adverse event to use.
Must be one of the two specific literal values: "pt" (Preferred Term) or
"soc_name" (System Organ Class name). Any other value will cause an error.
Defaults to "pt".
Analysis methods to use (passed to phv_signal).
Other arguments passed to phv_signal.
An optional BiocParallelParam instance
defining the parallel back-end to be used during evaluation.
A data.table object with contingency tables for the specified event set.