Read and Parse ATHENA VOCABULARIES data
athena(use = NULL, list = FALSE, force = FALSE, url = NULL)An atomic character specifying the files to use with values in "concept", "domain", "concept_class", "concept_relationship", "concept_ancestor", "concept_synonym", "drug_strength", "relationship", and "vocabulary".
A boolean value, should it only list files in the ATHENA VOCABULARIES data?
A boolean value. If set to TRUE, it indicates the retrieval of
VOCABULARIES data in the url directly, bypassing the cache.
A string of url for ATHENA VOCABULARIES data. You must provide it to cache the file when you firstly run this function.
if list = TRUE, an atomic character.
if list = FALSE, a data.table if use is a
string or otherwise a list of data.table.