Download and parse FAERS Quarterly Data files
An atomic integer indicates years for which data are required.
An atomic character, only "q1", "q2", "q3", and "q4" are allowed.
File format to used, only "ascii" and "xml" are availabe. Default: "ascii".
The destination directory for any downloads. Defaults to current working dir.
A string specifies the directory to extract files to. It will be created if necessary.
Extra handle options passed to each request new_handle.
A FAERSxml or FAERSascii object.
# you must change `dir`, as the file included in the package is sampled
data <- faers(2004, "q1",
dir = system.file("extdata", package = "faers"),
compress_dir = tempdir()
)
#> Finding 1 file already downloaded: aers_ascii_2004q1.zip