This function check if data for the years and quarters selected are available at FAERS to be downloaded.
faers_available(years, quarters, force = FALSE, internal = FALSE)An atomic integer indicates years for which data are required.
An atomic character, only "q1", "q2", "q3", and "q4" are allowed.
A boolean value. If set to TRUE, it indicates the retrieval of
information about all records' metadata in the FAERS Quarterly Data Extract
Files Site, bypassing the cache.
A boolean value. It determines whether to use the internal data associated with the package.
A logical indicates FAERS can have data for the years and
quarters required?