Packed all FAERSascii or FAERSxml objects into a single FAERSascii or
FAERSxml object. It is important to note that all data passed to these
functions via the ... argument must belong to the different FAERS
objects, indicating that they have the different period data (as defined by
faers_period).
faers_combine(...)Multiple FAERSxml or FAERSascii objects or a list containing
FAERSxml or FAERSascii objects. Objects can be standardized by
faers_standardize but cannot be de-duplicated by faers_dedup. If we
combine deduplicated objects from different quarterly data files, duplicate
reports will be introduced again.
A FAERSxml or FAERSascii object.
# the files included in the package are sampled
data1 <- faers_parse(
system.file("extdata", "aers_ascii_2004q1.zip", package = "faers"),
compress_dir = tempdir()
)
data2 <- faers_parse(
system.file("extdata", "faers_ascii_2017q2.zip", package = "faers"),
compress_dir = tempdir()
)
faers_combine(data1, data2)
#> → Combining all 2 <FAERS> Datas
#> FAERS data from 2 Quarterly ascii files
#> Total reports: 200 (with duplicates)