R/standardize.R
faers_standardize.RdStandardize FAERS Quarterly Data for Preferred Term and drug names
faers_standardize(object, ...)
# S4 method for class 'FAERSascii'
faers_standardize(object, meddra_path, add_smq = FALSE)A FAERSascii object.
Other arguments passed to specific methods.
A string, define the path of MedDRA directory.
A bool, indicates whether Standardised MedDRA Queries (SMQ)
should be added. If TRUE, "smq_content.asc", and "smq_list.asc" must exist.
A FAERSascii object.
#' # you must change `dir`, as the files included in the package are sampled
data <- faers(c(2004, 2017), c("q1", "q2"),
dir = system.file("extdata", package = "faers"),
compress_dir = tempdir()
)
#> Finding 2 files already downloaded: aers_ascii_2004q1.zip and
#> faers_ascii_2017q2.zip
#> → Combining all 2 <FAERS> Datas
if (FALSE) { # \dontrun{
# you should replace `meddra_path` with yours
data <- faers_standardize(data, meddra_path)
} # }